@@ -50,6 +50,7 @@ from .types.cluster_service import (
     DeleteNodePoolRequest,
     DnsCacheConfig,
     DNSConfig,
+    EphemeralStorageLocalSsdConfig,
     FastSocket,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
@@ -84,6 +85,7 @@ from .types.cluster_service import (
     ListOperationsResponse,
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
+    LocalNvmeSsdBlockConfig,
     LoggingComponentConfig,
     LoggingConfig,
     LoggingVariantConfig,
@@ -160,6 +162,7 @@ from .types.cluster_service import (
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
+    WindowsNodeConfig,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
 )
@@ -197,6 +200,7 @@ __all__ = (
     "DeleteClusterRequest",
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
+    "EphemeralStorageLocalSsdConfig",
     "FastSocket",
     "GPUSharingConfig",
     "GatewayAPIConfig",
@@ -231,6 +235,7 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LocalNvmeSsdBlockConfig",
     "LoggingComponentConfig",
     "LoggingConfig",
     "LoggingVariantConfig",
@@ -307,6 +312,7 @@ __all__ = (
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
     "VirtualNIC",
+    "WindowsNodeConfig",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
 )
