@@ -52,6 +52,7 @@ from .types.cluster_service import (
     DnsCacheConfig,
     DNSConfig,
     EphemeralStorageConfig,
+    EphemeralStorageLocalSsdConfig,
     FastSocket,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
@@ -89,6 +90,7 @@ from .types.cluster_service import (
     ListOperationsResponse,
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
+    LocalNvmeSsdBlockConfig,
     Location,
     LoggingComponentConfig,
     LoggingConfig,
@@ -155,6 +157,7 @@ from .types.cluster_service import (
     SetNodePoolSizeRequest,
     ShieldedInstanceConfig,
     ShieldedNodes,
+    StackType,
     StartIPRotationRequest,
     StatusCondition,
     TimeWindow,
@@ -169,6 +172,7 @@ from .types.cluster_service import (
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
+    WindowsNodeConfig,
     WindowsVersions,
     WorkloadALTSConfig,
     WorkloadCertificates,
@@ -212,6 +216,7 @@ __all__ = (
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
     "EphemeralStorageConfig",
+    "EphemeralStorageLocalSsdConfig",
     "FastSocket",
     "GPUSharingConfig",
     "GatewayAPIConfig",
@@ -249,6 +254,7 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LocalNvmeSsdBlockConfig",
     "Location",
     "LoggingComponentConfig",
     "LoggingConfig",
@@ -315,6 +321,7 @@ __all__ = (
     "SetNodePoolSizeRequest",
     "ShieldedInstanceConfig",
     "ShieldedNodes",
+    "StackType",
     "StartIPRotationRequest",
     "StatusCondition",
     "TimeWindow",
@@ -329,6 +336,7 @@ __all__ = (
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
     "VirtualNIC",
+    "WindowsNodeConfig",
     "WindowsVersions",
     "WorkloadALTSConfig",
     "WorkloadCertificates",
