@@ -46,6 +46,7 @@ from .cluster_service import (
     DnsCacheConfig,
     DNSConfig,
     EphemeralStorageConfig,
+    EphemeralStorageLocalSsdConfig,
     FastSocket,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
@@ -83,6 +84,7 @@ from .cluster_service import (
     ListOperationsResponse,
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
+    LocalNvmeSsdBlockConfig,
     Location,
     LoggingComponentConfig,
     LoggingConfig,
@@ -149,6 +151,7 @@ from .cluster_service import (
     SetNodePoolSizeRequest,
     ShieldedInstanceConfig,
     ShieldedNodes,
+    StackType,
     StartIPRotationRequest,
     StatusCondition,
     TimeWindow,
@@ -163,6 +166,7 @@ from .cluster_service import (
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
+    WindowsNodeConfig,
     WindowsVersions,
     WorkloadALTSConfig,
     WorkloadCertificates,
@@ -203,6 +207,7 @@ __all__ = (
     "DnsCacheConfig",
     "DNSConfig",
     "EphemeralStorageConfig",
+    "EphemeralStorageLocalSsdConfig",
     "FastSocket",
     "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
@@ -240,6 +245,7 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LocalNvmeSsdBlockConfig",
     "Location",
     "LoggingComponentConfig",
     "LoggingConfig",
@@ -317,6 +323,7 @@ __all__ = (
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
     "VirtualNIC",
+    "WindowsNodeConfig",
     "WindowsVersions",
     "WorkloadALTSConfig",
     "WorkloadCertificates",
@@ -326,5 +333,6 @@ __all__ = (
     "DatapathProvider",
     "NodePoolUpdateStrategy",
     "PrivateIPv6GoogleAccess",
+    "StackType",
     "UpgradeResourceType",
 )
